@@ -1,6 +1,6 @@
 import gettext
 
-ALLOWED_HOSTS = []
+ALLOWED_HOSTS = ['localhostn ']
 
 CACHES = {
     'default': {
